package com.akamai.mdt.id3tag;

import android.app.Activity;
import android.content.DialogInterface;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import android.view.WindowManager;
import android.widget.ProgressBar;
import android.widget.TextView;
import android.widget.Toast;

import com.akamai.id3tagextractor.ID3TagEventListener;
import com.akamai.id3tagextractor.ID3TagExtractorMessageHandler;
import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;

public class MainActivity extends Activity implements View.OnTouchListener, DialogInterface.OnCancelListener, IPlayerEventsListener, ID3TagEventListener {

    private VideoPlayerContainer mVideoContainer;

    private VideoPlayerView mVideoView;

    private ProgressBar mProgressBar;

    private TextView tagsTextView;

    private Boolean mWasPlaying = false;

    private int mCurrentPosition = 0;

    private final static String LICENSE = "YBtTdxkeJSzAyCfQg2THAmpH95eMusF0mdDWj0jlz0dd9Rrg7k9siyzrGf8lv1S3dPXoGouM7jnG7qN33x5k-Q==";

    private final static String VIDEO_URL = "http://sblanco.mediadev.edgesuite.net/id3/master.m3u8";

    private ID3TagExtractorMessageHandler mId3TagExtractorMessageHandler;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        // This prevents the device to go sleep
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);

        // Initialize the progress bar with the xml
        mProgressBar = (ProgressBar) findViewById(R.id.progressBar);

        // Get a reference to the VideoContainer object
        mVideoContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);

        tagsTextView = (TextView) findViewById(R.id.tagsTextView);

        // Set the decoding mode used by the Android SDK video control
        mVideoContainer.setMode(VideoPlayerContainer.MODE_HARDWARE_ADVANCED);

        // Get a reference to the VideoView object
        mVideoView = mVideoContainer.getVideoPlayer();

        // Set the progress to the player
        mVideoView.setProgressBarControl(mProgressBar);

        // Set your license
        mVideoView.setLicense(LICENSE);

        // Set the screen mode
        mVideoView.setFullScreen(true);
        mVideoView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);

        // Activate the logs
        mVideoView.setLogEnabled(true);

        // Configure the ID3Tag extractor
        mId3TagExtractorMessageHandler = new ID3TagExtractorMessageHandler();
        mId3TagExtractorMessageHandler.setVideoPlayerView(mVideoView);
        mId3TagExtractorMessageHandler.addEventListener(this);

        // Play the video
        mVideoView.playUrl(VIDEO_URL);

    }

    @Override
    protected void onResume() {
        Log.d("PlayerView", "OnResume");
        if (mWasPlaying) {
            mVideoView.playUrl(VIDEO_URL, mCurrentPosition);
            mWasPlaying = false;
        }
        super.onResume();
    }

    @Override
    protected void onPause() {
        Log.d("PlayerView", "OnPause");
        if (mVideoView.isPlaying() || mVideoView.isPaused()) {
            mCurrentPosition = mVideoView.getTimePosition();
            mWasPlaying = true;
        }
        mVideoView.stop();
        super.onPause();
    }

    @Override
    protected void onDestroy() {
        Log.d("PlayerView", "OnDestroy");
        mVideoView.stop();
        mVideoView.onDestroy();
        super.onDestroy();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    @Override
    public boolean onPlayerEvent(int iInEventType) {
        switch(iInEventType) {
            case IPlayerEventsListener.PLAYER_EVENT_TYPE_LOADING:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_FINISHED:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_START_PLAYING:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_ERROR:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_POSITION_UPDATE:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_START_REBUFFERING:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_END_REBUFFERING:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_SWITCH_REQUESTED:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_SWITCH:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_FULLSCREEN_MODE_CHANGE:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_SIZE_CHANGE:
                break;

            default:
                break;
        }

        return true;
    }

    @Override
    public boolean onPlayerExtendedEvent(int iInEventType, int arg1, int arg2) {
        if(iInEventType == IPlayerEventsListener.PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDEED)
            Log.d("Player", "Event Type: PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDED (" + iInEventType + ")");

        return true;
    }

    @Override
    public void onCancel(DialogInterface dialog)
    {
        finish();
    }

    @Override
    public boolean onTouch(View v, MotionEvent event)
    {
        return false;
    }

    @Override
    public boolean onFoundID3TagData(String text)
    {
        tagsTextView.setText(text);
        return true;
    }
}
