package com.akamai.ampdemoui;

import android.app.Activity;
import android.content.pm.ActivityInfo;
import android.content.res.Configuration;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.ImageButton;
import android.widget.ProgressBar;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.ui.listeners.IMediaPlayerControllerListener;
import com.akamai.ui.media.MediaPlayerController;

import java.math.MathContext;


public class MainActivity extends Activity implements IMediaPlayerControllerListener {

    private final String TAG = MainActivity.class.getSimpleName();

    // Video Player container object
    private VideoPlayerContainer mVideoPlayerContainer;

    // Video Player object
    private VideoPlayerView mVideoPlayer;

    // Control bar component
    private MediaPlayerController mMediaPlayerController;

    // Progress bar control
    private ProgressBar mProgressBar;

    // Android SDK License
    private static final String ANDROID_SDK_LICENSE = "eSwrM-aDq2lv2d35NMXiigENPdd1RFUKfL7LJbTfOfjP_MleTGEZLEJYXIqNVJ8dVN4R1eoj-VZ22Up0XCK_Wg==";

    // Media Asset url
    private static final String MEDIA_ASSET_URL = "http://multiplatform-f.akamaihd.net/i/multi/april11/hdworld/hdworld_,512x288_450_b,640x360_700_b,768x432_1000_b,1024x576_1400_m,1280x720_1900_m,1280x720_2500_m,1280x720_3500_m,.mp4.csmil/master.m3u8";

    // Keep current fullscreen mode
    private boolean mFullScreenMode, mWasPlaying;

    private int mCurrentPosition;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        validateFullScreenState();
        setContentView(R.layout.activity_main);

        if (savedInstanceState != null) {
            mFullScreenMode = savedInstanceState.getBoolean("FULLSCREEN");
            mCurrentPosition = savedInstanceState.getInt("CURRENT_POSITION");
        } else {
           mFullScreenMode = false;
            mCurrentPosition = 0;
        }

        // Initialize Progress Bar
        mProgressBar = (ProgressBar) findViewById(R.id.progressBar);
        // Initialize and configure the VideoPlayerContainer and VideoPlayerView
        mVideoPlayerContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);
        mVideoPlayerContainer.setMode(VideoPlayerContainer.MODE_AUTOMATIC);
        mVideoPlayer = mVideoPlayerContainer.getVideoPlayer();
        mVideoPlayer.setLicense(ANDROID_SDK_LICENSE);

        // Initialize UI Control bar
        mMediaPlayerController = (MediaPlayerController) findViewById(R.id.playerControls);

        setFullScreenState(mFullScreenMode);
        // Set the VideoPlayer object to the MediaController
        mMediaPlayerController.setVideoPlayerView(mVideoPlayer);

        // Set this object to listen SDK events and start playing the url
        mVideoPlayer.setProgressBarControl(mProgressBar);

        // Listen to control bar events
        mMediaPlayerController.setEventsListener(this);

        // Play Url
        mVideoPlayer.playUrl(MEDIA_ASSET_URL, mCurrentPosition);

        Log.i(TAG, "VERSION: "+mVideoPlayer.VERSION);

    }

    private void validateFullScreenState() {
        if (getResources().getConfiguration().orientation == Configuration.ORIENTATION_LANDSCAPE)
        {

            requestWindowFeature(Window.FEATURE_NO_TITLE);
            this.getWindow().setFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN, WindowManager.LayoutParams.FLAG_FULLSCREEN);
        }
        else if (getResources().getConfiguration().orientation == Configuration.ORIENTATION_PORTRAIT)
        {
            requestWindowFeature(Window.FEATURE_ACTION_BAR);
            this.getWindow().setFlags(WindowManager.LayoutParams.FLAG_FORCE_NOT_FULLSCREEN, WindowManager.LayoutParams.FLAG_FORCE_NOT_FULLSCREEN);
        }
    }

    @Override
    protected void onResume() {
        if (mWasPlaying) {
            mVideoPlayer.playUrl(MEDIA_ASSET_URL, mCurrentPosition);
            mWasPlaying = false;
        }
        super.onResume();
    }

    @Override
    protected void onPause() {
        if (mVideoPlayer.isPlaying() || mVideoPlayer.isPaused()) {
            mCurrentPosition = mVideoPlayer.getTimePosition();
            mWasPlaying = true;
        }
        mVideoPlayer.stop();
        super.onPause();
    }


    @Override
    protected void onDestroy() {
        mVideoPlayer.onDestroy();
        super.onDestroy();
    }

    @Override
    public void onSaveInstanceState(Bundle savedInstanceState) {
        savedInstanceState.putBoolean("FULLSCREEN", mFullScreenMode);
        savedInstanceState.putInt("CURRENT_POSITION", mCurrentPosition);
        // Always call the superclass so it can save the view hierarchy state
        super.onSaveInstanceState(savedInstanceState);
    }

    private void setFullScreenMode(boolean fullscreen)
    {
        if(fullscreen == mFullScreenMode)
            return;
        mFullScreenMode = fullscreen;
        // Checks the orientation of the screen
        if (fullscreen) {
            mVideoPlayer.setFullScreen(true);
            mVideoPlayer.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);

            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE);

        } else {
            mVideoPlayer.setFullScreen(false);
            mVideoPlayer.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_NONE);

            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
        }
        setFullScreenState(mFullScreenMode);
    }

    private void setFullScreenState(boolean fullscreen){
        if (fullscreen) {
            mMediaPlayerController.setCurrentFullScreenMode(MediaPlayerController.UI_MODE_FULLSCREEN);
        } else {
            mMediaPlayerController.setCurrentFullScreenMode(MediaPlayerController.UI_MODE_NON_FULLSCREEN);
        }
    }

    @Override
    public void onButtonClicked(int arg0) {

        if(arg0 == IMediaPlayerControllerListener.MEDIAPLAYERCONTROLLER_BUTTON_FULLSCREEN)
            setFullScreenMode(!mFullScreenMode);
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        return false;
    }
}
